package edu.sc.seis.cormorant.event;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.Properties;
import org.omg.CORBA.ORB;
import org.omg.CORBA.ORBPackage.InvalidName;
import org.omg.PortableServer.POA;
import org.omg.PortableServer.Servant;
import org.omg.PortableServer.ServantManager;
import org.omg.PortableServer.POAPackage.AdapterAlreadyExists;
import org.omg.PortableServer.POAPackage.InvalidPolicy;
import org.omg.PortableServer.POAPackage.WrongPolicy;
import edu.iris.Fissures.IfEvent.EventFactory;
import edu.iris.Fissures.IfEvent.EventFinder;
import edu.sc.seis.cormorant.DBProvidingAbstractController;
import edu.sc.seis.fissuresUtil.database.event.JDBCCatalog;
import edu.sc.seis.fissuresUtil.database.event.JDBCContributor;
import edu.sc.seis.fissuresUtil.database.event.JDBCEventAccess;

/**
 * @author crotwell Created on Dec 20, 2004
 */
public class EventController extends DBProvidingAbstractController {

    public EventController(Properties confProps, String serverPropName, ORB orb)
            throws Exception {
        super(confProps, serverPropName, orb);
        createEventDC(orb, confProps);
    }

    public Servant getServant() {
        return eventDC;
    }

    protected EventFinderImpl getEventFinderImpl(POA eventControllerPOA)
            throws SQLException {
        Connection dcConn = dbConnCreator.createConnection();
        JDBCEventAccess jdbcEventAccess = new JDBCEventAccess(dcConn);
        JDBCCatalog jdbcCatalog = new JDBCCatalog(dcConn);
        JDBCContributor jdbcContributor = new JDBCContributor(dcConn);
        return new EventFinderImpl(jdbcEventAccess,
                                   jdbcCatalog,
                                   jdbcContributor,
                                   eventControllerPOA);
    }

    private void createEventDC(ORB orb, Properties props) throws SQLException,
            AdapterAlreadyExists, InvalidPolicy, InvalidName, WrongPolicy {
        Connection dcConn = dbConnCreator.createConnection();
        JDBCEventAccess jdbcEventAccess = new JDBCEventAccess(dcConn);
        POA eventControllerPOA = createPOA(orb);
        eventDC = new EventDCImpl();
        EventFactoryImpl factoryImpl = new EventFactoryImpl(jdbcEventAccess,
                                                            eventControllerPOA);
        EventFinderImpl finderImpl = getEventFinderImpl(eventControllerPOA);
        EventFinder finder = finderImpl._this(orb);
        EventFactory factory = factoryImpl._this(orb);
        finderImpl.setEventFinder(finder);
        finderImpl.setEventFactory(factory);
        factoryImpl.setEventFactory(factory);
        factoryImpl.setEventFinder(finder);
        eventDC.setEventFinder(finder);
        EventLocator_impl eimpl = new EventLocator_impl(jdbcEventAccess,
                                                        eventControllerPOA);
        ServantManager locator = eimpl._this(orb);
        eventControllerPOA.set_servant_manager(locator);
    }

    private EventDCImpl eventDC;
}