package edu.sc.seis.cormorant.network;

import java.sql.SQLException;
import java.util.HashMap;
import java.util.Iterator;
import org.apache.log4j.Category;
import org.omg.CORBA.OBJECT_NOT_EXIST;
import org.omg.PortableServer.POA;
import org.omg.PortableServer.Servant;
import org.omg.PortableServer.ServantLocatorPOA;
import org.omg.PortableServer.ServantLocatorPackage.CookieHolder;
import edu.iris.Fissures.IfNetwork.ConcreteNetworkAccessHelper;
import edu.iris.Fissures.IfNetwork.ConcreteNetworkAccessPOA;
import edu.iris.Fissures.IfNetwork.NetworkAccess;
import edu.iris.Fissures.IfNetwork.NetworkId;
import edu.iris.Fissures.network.NetworkIdUtil;
import edu.sc.seis.fissuresUtil.database.NotFound;
import edu.sc.seis.fissuresUtil.database.network.JDBCChannel;
import edu.sc.seis.fissuresUtil.database.network.JDBCNetwork;

/**
 * NetworkServantLocator.java
 * 
 * 
 * Created: Thu Mar 15 12:27:25 2001
 * 
 * @author Philip Crotwell
 * @version
 */
public class NetworkServantLocator extends ServantLocatorPOA {

    public NetworkServantLocator(JDBCChannel jdbcChannel, POA myPOA)
            throws SQLException, NotFound {
        this.myPOA = myPOA;
        this.jdbcChannel = jdbcChannel;
        refresh();
    }

    public Servant preinvoke(byte[] oid,
                             POA adapter,
                             String operation,
                             CookieHolder the_cookie) {
        String idString = new String(oid);
        logger.debug("NetworkServantLocator: " + idString + " " + operation);
        if(idString.endsWith("NetworkAccess")) {
            return getNetworkAccessPOA(idString);
        } else {
            throw new OBJECT_NOT_EXIST();
        }
    }

    public void postinvoke(byte[] oid,
                           POA adapter,
                           String operation,
                           Object the_cookie,
                           Servant the_servant) {}

    NetworkAccess getNetworkAccess(NetworkId networkId) {
        String networkObjId = NetworkIdUtil.toString(networkId);
        logger.debug("getNetworkAccess: " + networkObjId);
        String key = networkIdToObjKey(networkId);
        return getNetworkAccess(key);
    }

    NetworkAccess getNetworkAccess(String key) {
        org.omg.CORBA.Object obj = null;
        // try {
        obj = myPOA.create_reference_with_id(key.getBytes(),
                                             ConcreteNetworkAccessHelper.id());
        // } catch (WrongPolicy e) {
        // // shouldn't happen???
        // logger.error("Wrong policy on POA:", e);
        // throw new org.omg.CORBA.UNKNOWN(e.getMessage());
        // }
        return ConcreteNetworkAccessHelper.narrow(obj);
    }

    public synchronized void refresh() throws SQLException, NotFound {
        networks.clear();
        JDBCNetwork jdbcNetwork = jdbcChannel.getNetworkTable();
        NetworkId[] allNets = jdbcNetwork.getAllNetworkIds();
        for(int i = 0; i < allNets.length; i++) {
            networks.put(networkIdToObjKey(allNets[i]), allNets[i]);
        }
    }

    public String networkIdToObjKey(NetworkId id) {
        return id.network_code + "_" + id.begin_time.date_time
                + "_NetworkAccess";
    }

    public String objKeyToNetworkCode(String objKey) {
        return objKey.substring(0, 2);
    }

    public NetworkId objKeyToNetworkId(String objKey) {
        return (NetworkId)networks.get(objKey);
    }

    ConcreteNetworkAccessPOA getNetworkAccessPOA(String networkObjId) {
        if(!networkAccessPoaMap.containsKey(networkObjId)) {
            networkAccessPoaMap.put(networkObjId,
                                    new ConcreteNetworkAccessImpl(jdbcChannel,
                                                                  objKeyToNetworkId(networkObjId)));
        }
        return (ConcreteNetworkAccessImpl)networkAccessPoaMap.get(networkObjId);
    }

    /**
     * @returns an iterator over all of the network object ids of
     *          NetworkAccessPOAs know.
     */
    Iterator getNetworkIterator() {
        return networks.keySet().iterator();
    }

    protected JDBCChannel jdbcChannel;

    protected HashMap networks = new HashMap();

    protected HashMap networkAccessPoaMap = new HashMap();

    protected POA myPOA;

    static Category logger = Category.getInstance(NetworkServantLocator.class.getName());
} // NetworkServantLocator
