package edu.sc.seis.cormorant.seismogram;

import java.io.IOException;
import java.sql.SQLException;
import java.text.ParseException;
import java.util.Properties;
import org.omg.CORBA.ORB;
import org.omg.PortableServer.Servant;
import edu.sc.seis.cormorant.DBProvidingAbstractController;
import edu.sc.seis.fissuresUtil.database.seismogram.JDBCSeismogramFiles;
import edu.sc.seis.fissuresUtil.rt130.LeapSecondApplier;

/**
 * @author fenner
 * 
 */
public class SodDBSeismogramController extends DBProvidingAbstractController {

    public SodDBSeismogramController(Properties confProps,
                                     String serverPropName,
                                     ORB orb) throws SQLException, IOException,
            ParseException {
        super(confProps, serverPropName, orb);
        boolean ignoreNetworkTimes = false;
        if(confProps.containsKey(IGNORE_NETWORK_TIMES)
                && confProps.getProperty(IGNORE_NETWORK_TIMES).equals("true")) {
            ignoreNetworkTimes = true;
        }
        LeapSecondApplier.addLeapSeconds(confProps.getProperty("leapSecondTimeFileLoc"));
        LeapSecondApplier.addCorrections(confProps.getProperty("powerUpTimeFileLoc"));
        JDBCSeismogramFiles seisFileDb = new JDBCSeismogramFiles(dbConnCreator.createConnection());
        sl = new SodDBSeismogramServer(seisFileDb, ignoreNetworkTimes);
    }

    public Servant getServant() {
        return sl;
    }

    private SodDBSeismogramServer sl;

    private final String IGNORE_NETWORK_TIMES = "cormorant.servers.SeisDC.ignoreNetworkTimes";
}
