package edu.sc.seis.cormorant.nameServer;

import java.util.Properties;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.varia.NullAppender;
import edu.iris.Fissures.TimeRange;
import edu.iris.Fissures.IfEvent.EventAccess;
import edu.iris.Fissures.IfEvent.EventDCOperations;
import edu.iris.Fissures.IfEvent.EventFinder;
import edu.iris.Fissures.IfEvent.EventSeqIterHolder;
import edu.iris.Fissures.model.AllVTFactory;
import edu.iris.Fissures.model.GlobalAreaImpl;
import edu.iris.Fissures.model.MicroSecondDate;
import edu.iris.Fissures.model.QuantityImpl;
import edu.iris.Fissures.model.TimeInterval;
import edu.iris.Fissures.model.UnitImpl;
import edu.sc.seis.fissuresUtil.chooser.ClockUtil;
import edu.sc.seis.fissuresUtil.namingService.FissuresNamingService;


public class LocalNameServerTest {

    
    public static void main(String[] args) throws Exception {
        
        BasicConfigurator.configure(new NullAppender());
        // Initialize the ORB. This must be done before the corba system can be
        // used.
        org.omg.CORBA_2_3.ORB orb = (org.omg.CORBA_2_3.ORB)org.omg.CORBA.ORB.init(new String[] {},
                                                                                  new Properties());
        // Registers the FISSURES classes with the ORB
        new AllVTFactory().register(orb);
        // Pick a name server to get FISSURES servers.
        FissuresNamingService namingService = new FissuresNamingService(orb);
        namingService.setNameServiceCorbaLoc("IOR:000000000000002B49444C3A6F6D672E6F72672F436F734E616D696E672F4E616D696E67436F6E746578744578743A312E30000000000001000000000000003C000102000000000E3132392E3235322E33352E31370018E40000000B2F001416204B3C04210D0F00000000010000000000000008000000004A414300");
        EventDCOperations eventDC = namingService.getEventDC("localhost",
                                                             "EventDC");
        EventFinder finder = eventDC.a_finder();
        EventSeqIterHolder iter = new EventSeqIterHolder();
        MicroSecondDate now = ClockUtil.now();
        MicroSecondDate oneWeekAgo = now.subtract(new TimeInterval(7,
                                                                   UnitImpl.DAY));
        TimeRange oneWeek = new TimeRange(oneWeekAgo.getFissuresTime(),
                                          now.getFissuresTime());
        String[] magTypes = {};// Empty array accepts any type
        String[] catalogs = {};// Empty array accepts any catalog
        String[] contributors = {};// Empty array accepts any contributor
        EventAccess[] events = finder.query_events(new GlobalAreaImpl(),
                                                   new QuantityImpl(0,//min depth
                                                                    UnitImpl.KILOMETER),
                                                   new QuantityImpl(1000,//max depth
                                                                    UnitImpl.KILOMETER),
                                                   oneWeek,
                                                   magTypes,
                                                   5.0f,// min magnitude
                                                   10.0f,// max magnitude
                                                   catalogs,
                                                   contributors,
                                                   500,//Number of events to return
                                                   iter);//Allows access to additional events
        System.out.println("got " + events.length + " events");
        
        
        
    }

}
